package DSCS::Memory::Users; #A table/row class
use 5.010001;
use strict;
use warnings;
use utf8;
use parent qw(DSCS::Memory);

sub is_base_class{return 0}
my $TABLE_NAME = 'users';

sub TABLE {return $TABLE_NAME}
sub PRIMARY_KEY{return 'id'}
my $COLUMNS = [
             'id',
             'group_id',
             'login_name',
             'login_password',
             'name',
             'email',
             'disabled',
             'balance',
             'dummy_dec',
             'nullable_column'
           ];

sub COLUMNS {return $COLUMNS}
my $ALIASES = {};

sub ALIASES {return $ALIASES}
my $CHECKS = {
            'nullable_column' => {
                                   'allow' => sub { "DUMMY" }
                                 },
            'login_password' => {
                                  'allow' => sub { "DUMMY" },
                                  'defined' => 1,
                                  'required' => 1
                                },
            'name' => {
                        'required' => 1,
                        'default' => '',
                        'allow' => sub { "DUMMY" },
                        'defined' => 1
                      },
            'balance' => {
                           'required' => 1,
                           'allow' => qr/^-?\d{1,6}(?:\.\d{0,2})?$/x,
                           'default' => '0.00',
                           'defined' => 1
                         },
            'email' => {
                         'required' => 1,
                         'default' => 'email@domain.com',
                         'allow' => sub { "DUMMY" },
                         'defined' => 1
                       },
            'group_id' => {
                            'required' => 1,
                            'allow' => qr/^-?\d{1,11}$/x,
                            'defined' => 1
                          },
            'disabled' => {
                            'required' => 1,
                            'allow' => qr/^-?\d{1,1}$/x,
                            'default' => '0',
                            'defined' => 1
                          },
            'login_name' => {
                              'required' => 1,
                              'allow' => sub { "DUMMY" },
                              'defined' => 1
                            },
            'id' => {
                      'allow' => qr/^-?\d{1,}$/x
                    },
            'dummy_dec' => {
                             'default' => '0',
                             'allow' => qr/^-?\d{1,8}(?:\.\d{0,0})?$/x,
                             'defined' => 1,
                             'required' => 1
                           }
          };

sub CHECKS {return $CHECKS}

__PACKAGE__->QUOTE_IDENTIFIERS(0);
#__PACKAGE__->BUILD;#build accessors during load

1;

=pod

=encoding utf8

=head1 NAME

A class for TABLE users in schema main

=head1 SYNOPSIS

=head1 DESCRIPTION

=head1 COLUMNS

Each column from table C<users> has an accessor method in this class.

=head2 id

=head2 group_id

=head2 login_name

=head2 login_password

=head2 name

=head2 email

=head2 disabled

=head2 balance

=head2 dummy_dec

=head2 nullable_column

=head1 ALIASES

=head1 GENERATOR

L<DBIx::Simple::Class::Schema>

=head1 SEE ALSO
L<DSCS::Memory>, L<DBIx::Simple::Class>, L<DBIx::Simple::Class::Schema>

=head1 AUTHOR

builder

=cut
